<?php
function _addTopicPerms(&$tof,$vars) {
	if (is_array($vars['Groups']) && is_array($vars['_Perms']))
		addTopicPerms(
			$tof,
			$vars['_TopicID'],
			$vars['Groups'],
			$vars['_Perms']);
}

function addTopicPerms(&$tof,$topicID,$groups,$perms) {
	foreach($perms as $perm) {
		  foreach($groups as $groupID) {
			  $tof->ct->addTopicPerm($topicID,$groupID,$perm);
		  }
	}
}
?>